Module buffer
gltf_
json
1.4.1
Module buffer
Module Items
Structs
In gltf_
json::
extensions
gltf_json
::
extensions
Module
buffer
Contains
Buffer
,
View
, and other related data structures.
Structs

Buffer
A buffer points to binary data representing geometry, animations, or skins.
View
A view into a buffer generally representing a subset of the buffer.